summaryrefslogtreecommitdiffstats
path: root/gst/camerabin/gstcamerabin.c
diff options
context:
space:
mode:
authorRené Stadler <mail@renestadler.de>2009-02-11 01:24:51 +0200
committerRené Stadler <mail@renestadler.de>2009-02-11 01:59:39 +0200
commit6675318107e4cb465dcad37aafec704d46e12a9f (patch)
tree152ac8d9c10925f1adbbbba34fd85ddc2e05ddbe /gst/camerabin/gstcamerabin.c
parentc7dfd538991519758e1157b2f2044a686ab0d1c1 (diff)
downloadgst-plugins-bad-6675318107e4cb465dcad37aafec704d46e12a9f.tar.gz
gst-plugins-bad-6675318107e4cb465dcad37aafec704d46e12a9f.tar.bz2
gst-plugins-bad-6675318107e4cb465dcad37aafec704d46e12a9f.zip
camerabin: Use v4l2src as default source.
Diffstat (limited to 'gst/camerabin/gstcamerabin.c')
-rw-r--r--gst/camerabin/gstcamerabin.c11
1 files changed, 4 insertions, 7 deletions
diff --git a/gst/camerabin/gstcamerabin.c b/gst/camerabin/gstcamerabin.c
index a720809f..1ad01899 100644
--- a/gst/camerabin/gstcamerabin.c
+++ b/gst/camerabin/gstcamerabin.c
@@ -218,11 +218,8 @@ static guint camerabin_signals[LAST_SIGNAL];
#define USE_COLOR_CONVERTER 1
-/* FIXME: use autovideosrc
- * v4l2camsrc should have GST_RANK_PRIMARY in maemo and _NONE in plugins-bad
- * for now */
-static const char SRC_VID_SRC[] = "v4l2camsrc";
-/*static const char SRC_VID_SRC[] = "v4l2src"; */
+/* FIXME: Make sure this can work with autovideosrc and use that. */
+static const char SRC_VID_SRC[] = "v4l2src";
static const char ZOOM_CROP[] = "videocrop";
static const char ZOOM_SCALE[] = "videoscale";
@@ -2017,14 +2014,14 @@ gst_camerabin_class_init (GstCameraBinClass * klass)
* GstCameraBin:videosrc:
*
* Set up a video source element.
* By default "v4l2camsrc" will be the src element.
* This property can only be set while #GstCameraBin is in NULL state.
* The ownership of the element will be taken by #GstCameraBin.
*/
g_object_class_install_property (gobject_class, ARG_VIDEO_SRC,
g_param_spec_object ("videosrc", "Video source element",
- "Video source GStreamer element (default is v4l2camsrc)",
+ "Video source GStreamer element (default is v4l2src)",
GST_TYPE_ELEMENT, G_PARAM_READWRITE));
/**
* GstCameraBin:audiosrc:
@@ -2017,14 +2014,14 @@ gst_camerabin_class_init (GstCameraBinClass * klass)
*
* Set up a video source element.
- * By default "v4l2camsrc" will be the src element.
+ * By default "v4l2src" will be the src element.
* This property can only be set while #GstCameraBin is in NULL state.
* The ownership of the element will be taken by #GstCameraBin.